"""Auto-generated and hand-written API namespace modules.

The ``_generated`` module is produced by ``scripts/generate_bindings.py``
from the YAML schema.  Import namespaces from here for convenience.
"""

from pymoonraker.api._generated import (
    AccessNamespace,
    AnnouncementsNamespace,
    DatabaseNamespace,
    FilesNamespace,
    HistoryNamespace,
    JobQueueNamespace,
    MachineNamespace,
    PowerNamespace,
    PrinterNamespace,
    ServerNamespace,
    UpdateManagerNamespace,
    WebcamsNamespace,
)

__all__ = [
    "AccessNamespace",
    "AnnouncementsNamespace",
    "DatabaseNamespace",
    "FilesNamespace",
    "HistoryNamespace",
    "JobQueueNamespace",
    "MachineNamespace",
    "PowerNamespace",
    "PrinterNamespace",
    "ServerNamespace",
    "UpdateManagerNamespace",
    "WebcamsNamespace",
]
